import { CONFIG } from './config';
import { ValidationError, errorHandler } from './errors';
import { formatters } from './formatters';
import { createStreamHandler } from './stream';
import { validateApiKey } from './auth';
import { handleCors } from './cors';
import { STREAM_HEADERS, JSON_HEADERS } from './headers';

// 验证并获取配置
async function getConfig(env) {
  if (!env.AI) throw new Error('AI binding not configured');
  if (!env.API_KEY) throw new Error('API_KEY not set');

  let models = await env.AI.models();
  const apiKeys = new Set(env.API_KEY.split(',').map(k => k.trim()));
  
  if (env.MODELS) {
    const allowedModels = new Set(env.MODELS.split(',').map(m => m.trim()));
    models = models.filter(m => allowedModels.has(m.name));
    if (!models.length) {
      throw new Error('No valid models configured. Check your MODELS environment variable.');
    }
  }

  return {
    apiKeys,
    models
  };
}

// 参数验证
function validateParams(params, type) {
  // 验证内容
  if (type === 'prompt' ? !params.prompt : !Array.isArray(params.messages)) {
    throw new ValidationError(
      `Invalid ${type}`,
      `invalid_${type}`,
      type
    );
  }

  // 验证参数范围
  const validatedParams = {
    model: params.model,
    stream: params.stream || false,
    [type]: params[type]
  };

  for (const [param, range] of Object.entries(CONFIG.PARAM_RANGES)) {
    const value = params[param] ?? range.default;
    if (value !== undefined) {
      if ((range.type === 'integer' && !Number.isInteger(value)) ||
          value < range.min || (range.max && value > range.max)) {
        throw new ValidationError(
          `${param} must be ${range.type === 'integer' ? 'an integer ' : ''}between ${range.min} and ${range.max}`,
          `invalid_${param}`,
          param
        );
      }
      validatedParams[param] = value;
    }
  }

  return validatedParams;
}

export default {
  async fetch(request, env, ctx) {
    try {
      // CORS预检处理
      const corsResponse = handleCors(request);
      if (corsResponse) return corsResponse;

      const url = new URL(request.url);
      if (!url.pathname.startsWith('/v1/')) {
        return new Response('Not Found', { status: 404 });
      }

      const config = await getConfig(env);
      validateApiKey(request.headers.get("Authorization"), config.apiKeys);

      switch (url.pathname) {
        case "/v1/models":
          if (request.method !== "GET") {
            throw new ValidationError("Method not allowed", "method_not_allowed");
          }
          return Response.json({
            object: "list",
            data: config.models
          }, {
            headers: JSON_HEADERS
          });

        case "/v1/completions":
        case "/v1/chat/completions": {
          if (request.method !== "POST") {
            throw new ValidationError("Method not allowed", "method_not_allowed");
          }
          
          const isChat = url.pathname === "/v1/chat/completions";
          const type = isChat ? "chat" : "completion";
          const requestData = await request.json();
          const validatedParams = validateParams(
            requestData, 
            isChat ? "messages" : "prompt"
          );
          const cfParams = formatters.toCloudflare(validatedParams, type);
          const response = await env.AI.run(validatedParams.model, cfParams);
          
          return validatedParams.stream
            ? new Response(
                response.pipeThrough(createStreamHandler(type, validatedParams.model)),
                { headers: STREAM_HEADERS }
              )
            : Response.json(
                formatters.toOpenAI(response, type, validatedParams.model),
                { headers: JSON_HEADERS }
              );
        }

        default:
          throw new ValidationError("Not Found", "not_found");
      }
    } catch (error) {
      return errorHandler(error);
    }
  }
};
